import dataiku
import pandas as pd
import pm4py
from pm4py.algo.discovery.inductive import algorithm as inductive_miner
from process_mining.process_mining import mine_process
from data_management import get_managed_folder_id_with_folder_name, write_pickle_in_dss_folder, read_pickle_from_dss_folder

def delete_process_in_folder(process):
    input_folder = dataiku.Folder("1rhVX912")
    input_folder.delete_path(process + '_dfg.p')
    input_folder.delete_path(process + '_filters.p')
    input_folder.delete_path(process + '_petri.p')
    remove_process(process)

def save_process_in_folder(project, process_name, data, filters):
    event_log = pm4py.format_dataframe(data, case_id='case', activity_key='activity', timestamp_key='timestamp')
    net, im, fm = inductive_miner.apply(event_log, variant=inductive_miner.Variants.IM_CLEAN)
    workflow_mined, start_end, activities = mine_process(data, 'case', 'activity', 'timestamp', transition='performance')
    folder_id = get_managed_folder_id_with_folder_name(project, "saved_processes")
    petri_net = {'pn': net, 'im': im, 'fm': fm}
    write_pickle_in_dss_folder(petri_net, process_name + '_petri.p', folder_id)
    dfg = {'workflow_mined': workflow_mined, 'start_end': start_end, 'activities': activities}
    write_pickle_in_dss_folder(dfg, process_name + '_dfg.p', folder_id)
    write_pickle_in_dss_folder(filters, process_name + '_filters.p', folder_id)
    add_process(process_name)

def add_process(process):
    available_processes = dataiku.Dataset("available_processes")
    try:
        process_df = available_processes.get_dataframe()
    except:
        process_df = pd.DataFrame()
    process_df[process] = [1]
    available_processes.write_with_schema(process_df)

def remove_process(process):
    available_processes = dataiku.Dataset("available_processes")
    process_df = available_processes.get_dataframe()
    process_df.drop(process, axis=1, inplace=True)
    available_processes.write_with_schema(process_df)