from dash import dcc, html
import dataiku
import dash_bootstrap_components as dbc
from webapp.styles import *

process_input_name = dcc.Input(id='saved-process-name',
                               type='text',
                               placeholder='Process Name',
                               style={'height': '36px', 'width': '100%', 'border-radius': 0})

def saved_processes_dropdown(default_value=None):
    input_folder = dataiku.Folder("1rhVX912")
    paths = input_folder.list_paths_in_partition()
    names = [name.replace('_petri.p', '').replace('/', '') for name in paths if '_petri.p' in name]
    if default_value is None and len(names)>0:
        default_value = names[0]
    saved_processes_dropdown_object = dcc.Dropdown(
            id='saved-processes-dropdown',
            options=[{'label': name, 'value': name} for name in names],
            value=default_value,
            style={'border-radius': 0})
    return saved_processes_dropdown_object

def process_dropdown(default_value=None, tab='discovery'):
    if tab == 'discovery':
        title = 'Reference process'
        return dbc.Col([html.P(title, style={'font-weight': 'bold'}),
            dbc.Row([dbc.Col(id='saved-processes-container',
                             children=saved_processes_dropdown(default_value), 
                             style={'padding': 0}, 
                             md=10),
                     dbc.Col(html.Button(html.I(className='fas fa-trash'), id='delete-process', 
                                        style=button_style_delete),
                            md=2, style={'padding-right': 0,
                                         'padding-top': '6px'})],
                   style={'margin-top': '7px', 'margin-bottom': '7px',
                         'margin-left': 0, 'margin-right': 0})
                   ])
    else:
        title = 'Compare reference process'
        return dbc.Col([html.P(title, style={'font-weight': 'bold'}),
                dbc.Row([dbc.Col(id='saved-processes-container',
                                 children=saved_processes_dropdown(default_value), 
                                 style={'padding': 0}, 
                                 md=12),
                        dbc.Button('dummy', id='apply-button', style={'display': 'None'})],
                       style={'margin-top': '7px', 'margin-bottom': '7px',
                             'margin-left': 0, 'margin-right': 0})
                       ])

def process_header_menu():
    return html.Div(children=process_dropdown(),
                       id='process-header')