Conformance checking is the task of comparing a set of traces with a predefined process. It creates insights into how well real-world data conforms to a user-defined process, and also monitors continuously how new traces fit the process. Conformance checking can take multiple forms, depending on the format of the saved process and business expectations.

# Token-Based Replay

Token-Based Replay is the standard starting point for conformance checking. It consists in computing the four counters for each trace that record if transitions occurred according to the Petri Net or not: 

- Produced tokens:  _p_ 
- Consumed tokens:  _c_ 
- Missing tokens:  _m_ 
- Remaining tokens:  _r_ 

A complete description of the technique can be found in the [referenced book](article:9) or in this [wikipedia article](https://en.wikipedia.org/wiki/Token-based_replay).

Then the fitness score is computed:

```math
{\displaystyle \frac{1}{2}(1 - \frac{m}{c}) + \frac{1}{2}(1 - \frac{r}{p})}
```

# Other types of conformance checking

The conformance checking describes above relates only to the succession of steps from the start to the end of a trace. Other considerations include the time for a given transition or a set of transitions, or the homogeneity of some additional parameters across the steps of a trace.

For instance, depending on the use case, alerts can be raised if the total execution of a process exceeds a value according to business expertise or to a product's specifications. Similarly, the transition time from one step to another could be compared to user-defined bounds or to the distribution of such transitions within the whole log file to control if they remain in an acceptable range.

Regarding conformance related to other parameters, one could check if all the steps have been executed by the same resource, which might be a person or a business unit. Suppose the logs contain geographical information for example. In that case, the business logic might dictate that some geographical patterns are not conforming, like moving back and forth between two places or taking excessive detours.